@@ -7,11 +7,7 @@
 
 #include "konqapplication.h"
 
-#if QT_VERSION_MAJOR < 6
-extern "C" Q_DECL_EXPORT int kdemain(int argc, char **argv)
-#else
 int main(int argc, char **argv)
-#endif
 {
     QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts); // says QtWebEngine. Note: this must be set before creating the application
     KonquerorApplication app(argc, argv);
