@@ -6,7 +6,7 @@
 */
 
 #include "konqundomanager.h"
-#include "konqsettingsxt.h"
+#include "konqsettings.h"
 #include "konqcloseditem.h"
 #include "konqclosedwindowsmanager.h"
 #include <QAction>
@@ -132,7 +132,7 @@ void KonqUndoManager::slotAddClosedWindowItem(KonqUndoManager *real_sender, Konq
 
     populate();
 
-    if (m_closedItemList.size() >= KonqSettings::maxNumClosedItems()) {
+    if (m_closedItemList.size() >= Konq::Settings::maxNumClosedItems()) {
         const KonqClosedItem *last = m_closedItemList.last();
         const KonqClosedTabItem *lastTab =
             dynamic_cast<const KonqClosedTabItem *>(last);
@@ -189,15 +189,10 @@ void KonqUndoManager::undoClosedItem(int index)
 
     const KonqClosedTabItem *closedTabItem =
         dynamic_cast<const KonqClosedTabItem *>(closedItem);
-    KonqClosedRemoteWindowItem *closedRemoteWindowItem =
-        dynamic_cast<KonqClosedRemoteWindowItem *>(closedItem);
     KonqClosedWindowItem *closedWindowItem =
         dynamic_cast<KonqClosedWindowItem *>(closedItem);
     if (closedTabItem) {
         emit openClosedTab(*closedTabItem);
-    } else if (closedRemoteWindowItem) {
-        m_cwManager->removeClosedWindowItem(this, closedRemoteWindowItem);
-        emit openClosedWindow(*closedRemoteWindowItem);
     } else if (closedWindowItem) {
         m_cwManager->removeClosedWindowItem(this, closedWindowItem);
         emit openClosedWindow(*closedWindowItem);
@@ -237,7 +232,7 @@ void KonqUndoManager::addClosedTabItem(KonqClosedTabItem *closedTabItem)
 {
     populate();
 
-    if (m_closedItemList.size() >= KonqSettings::maxNumClosedItems()) {
+    if (m_closedItemList.size() >= Konq::Settings::maxNumClosedItems()) {
         const KonqClosedItem *last = m_closedItemList.last();
         const KonqClosedTabItem *lastTab =
             dynamic_cast<const KonqClosedTabItem *>(last);
@@ -275,7 +270,7 @@ void KonqUndoManager::clearClosedItemsList(bool onlyInthisWindow)
         if (closedTabItem) {
             delete closedTabItem;
         } else if (closedWindowItem && !onlyInthisWindow) {
-            m_cwManager->removeClosedWindowItem(this, closedWindowItem, true);
+            m_cwManager->removeClosedWindowItem(this, closedWindowItem);
             delete closedWindowItem;
         }
     }
