@@ -42,6 +42,7 @@ class WebEngineNavigationExtension;
 class WebEngineWallet;
 class KPluginMetaData;
 class WebEnginePartControls;
+class QTemporaryDir;
 
 namespace KonqInterfaces {
     class DownloadJob;
@@ -158,6 +159,8 @@ public:
 
     Q_PROPERTY(bool isWebEnginePart READ isWebEnginePart)
 
+    static QTemporaryDir& temporaryDir();
+
 public Q_SLOTS:
     void exitFullScreen();
     void setInspectedPart(KParts::ReadOnlyPart *part);
@@ -167,6 +170,8 @@ public Q_SLOTS:
      */
     void displayActOnDownloadedFileBar(KonqInterfaces::DownloadJob *job);
 
+    void displayPrintPreview();
+
 protected:
     /**
      * Re-implemented for internal reasons. API remains unaffected.
